Struct codespan_reporting::Label
[−]
[src]
pub struct Label {
pub span: ByteSpan,
pub message: Option<String>,
pub style: LabelStyle,
}A label describing an underlined region of code associated with a diagnostic
Fields
span: ByteSpan
The span we are going to include in the final snippet.
message: Option<String>
A message to provide some additional information for the underlined code.
style: LabelStyle
The style to use for the label.
Methods
impl Label[src]
pub fn new(span: ByteSpan, style: LabelStyle) -> Label[src]
pub fn new_primary(span: ByteSpan) -> Label[src]
pub fn new_secondary(span: ByteSpan) -> Label[src]
pub fn with_message<S: Into<String>>(self, message: S) -> Label[src]